# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/content/content_management.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/content/content_management.proto',
  package='ai.cogneed.api.content',
  syntax='proto3',
  serialized_options=_b('\n\026ai.cogneed.api.contentP\001'),
  serialized_pb=_b('\n>cogneed-protos/ai/cogneed/api/content/content_management.proto\x12\x16\x61i.cogneed.api.content\x1a*cogneed-protos/ai/cogneed/api/common.proto\"%\n\x14\x43reateUseCaseRequest\x12\r\n\x05title\x18\x01 \x01(\t2v\n\x18\x43ontentManagementService\x12Z\n\rCreateUseCase\x12,.ai.cogneed.api.content.CreateUseCaseRequest\x1a\x1b.ai.cogneed.api.AckResponseB\x1a\n\x16\x61i.cogneed.api.contentP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_CREATEUSECASEREQUEST = _descriptor.Descriptor(
  name='CreateUseCaseRequest',
  full_name='ai.cogneed.api.content.CreateUseCaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='ai.cogneed.api.content.CreateUseCaseRequest.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=171,
)

DESCRIPTOR.message_types_by_name['CreateUseCaseRequest'] = _CREATEUSECASEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateUseCaseRequest = _reflection.GeneratedProtocolMessageType('CreateUseCaseRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATEUSECASEREQUEST,
  __module__ = 'cogneed_protos.ai.cogneed.api.content.content_management_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.content.CreateUseCaseRequest)
  ))
_sym_db.RegisterMessage(CreateUseCaseRequest)


DESCRIPTOR._options = None

_CONTENTMANAGEMENTSERVICE = _descriptor.ServiceDescriptor(
  name='ContentManagementService',
  full_name='ai.cogneed.api.content.ContentManagementService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=173,
  serialized_end=291,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateUseCase',
    full_name='ai.cogneed.api.content.ContentManagementService.CreateUseCase',
    index=0,
    containing_service=None,
    input_type=_CREATEUSECASEREQUEST,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONTENTMANAGEMENTSERVICE)

DESCRIPTOR.services_by_name['ContentManagementService'] = _CONTENTMANAGEMENTSERVICE

# @@protoc_insertion_point(module_scope)
